@@ -3,9 +3,9 @@
 #'
 #' @param website a url of a new source in the format "news.ycombinator.com"
 #' @param rss_table a dataframe with urls and rss feeds in case you
-#' #need to construct your own out of websites not in the included database.
-#' #Be sure to have the same format as the included data. See `R/package_rss.R`
-#' #for details.
+#' need to construct your own out of websites not in the included database.
+#' Be sure to have the same format as the included data. See `R/package_rss.R`
+#' for details.
 #'
 #'
 
@@ -21,9 +21,9 @@ check_url <- function(website = "ycombinator.com", rss_table = package_rss) {
   if (!any(index)) {
     stop(
       paste(
-        "Can't find website:",
+        "Can't find the website:",
         website,
-        "in our database. Please check if this is a valid website name, or try to fetch the feed directly with tydyrss::tidyfeed()'.",
+        "in our database. Please check if this is a valid website name, or try to fetch the feed directly with 'tydyrss::tidyfeed()'.",
         sep = " "
       )
     )
